@@ -14,13 +14,22 @@ from pdf2image import convert_from_bytes
 
 from disclosure_extractor.calculate import estimate_investment_net_worth, color
 from disclosure_extractor.data_processing import process_document
-from disclosure_extractor.image_processing import extract_contours_from_page
+from disclosure_extractor.image_processing import (
+    extract_contours_from_page,
+    CheckboxesNotFound,
+)
+from disclosure_extractor.judicial_watch_utils import (
+    get_investment_pages,
+    extract_section_VII,
+    extract_section_I_to_VI,
+    identify_sections,
+    get_text_fields,
+    process_addendum,
+)
 
 
 def print_results(results):
-    """Display the extraction in a nice table printout.
-
-    """
+    """Display the extraction in a nice table printout."""
     cd = {}
     for k, v in results["sections"].items():
         columns = results["sections"][k]["columns"]
@@ -61,7 +70,7 @@ def print_results(results):
                 "|",
             )
             print("\033[1m", end="")
-            print("|", k.ljust(len(" | ".join(headers))-1), "\033[0m", "|")
+            print("|", k.ljust(len(" | ".join(headers)) - 1), "\033[0m", "|")
             print(
                 "|",
                 "-" * len(" | ".join(headers)),
@@ -76,6 +85,8 @@ def print_results(results):
             cd[k] = x
             print("|", "_" * len(" | ".join(headers)), "|")
 
+    if "wealth" not in results.keys():
+        return
     print("\n", "Wealth", "\n===============================")
     net_worth = results["wealth"]["investment_net_worth"]
     gains = results["wealth"]["income_gains"]
@@ -97,7 +108,10 @@ def print_results(results):
     if net_worth[0] > 0:
         percent = 100 * gains[0] / (net_worth[0] - gains[0])
         yoy_percent = (
-            color.RED + color.BOLD + str("{:,.2f}%".format(percent)) + color.END
+            color.RED
+            + color.BOLD
+            + str("{:,.2f}%".format(percent))
+            + color.END
             if percent > 5
             else str("{:,.2f}%".format(percent))
         )
@@ -152,7 +166,11 @@ def process_financial_document(
     logging.info("Document is %s pages long" % page_total)
 
     logging.info("Determining document structure")
-    document_structure, check_count = extract_contours_from_page(pages)
+    try:
+        document_structure, check_count = extract_contours_from_page(pages)
+    except:
+        return {"success": False, "msg": CheckboxesNotFound}
+
     if check_count < 8:
         logging.warning("Failed to extract document structure")
         return {"success": False, "msg": "Failed to process document properly"}
@@ -162,11 +180,62 @@ def process_financial_document(
     results["page_count"] = page_total
     results["pdf_size"] = len(pdf_bytes)
 
-    try:
-        results["wealth"] = estimate_investment_net_worth(results)
-    except:
-        pass
+    results["wealth"] = estimate_investment_net_worth(results)
 
     results["success"] = True
     return results
 
+
+def process_judicial_watch(
+    file_path=None, url=None, pdf_bytes=None, show_logs=None
+):
+    """This is the second and more brute force method for ugly PDFs.
+
+    This method relies upon our own slicing and dicing of the image.
+    """
+    if show_logs:
+        logging.getLogger().setLevel(logging.INFO)
+
+    logging.info("Beginning Extraction of Financial Document")
+
+    if not file_path and not url and not pdf_bytes:
+        logging.warning(
+            "\n\n--> No file, url or pdf_bytes submitted<--\n--> Exiting early\n"
+        )
+        return
+
+    if file_path:
+        logging.info("Opening PDF document from path")
+        pdf_bytes = open(file_path, "rb").read()
+    if url:
+        logging.info("Downloading PDF from URL")
+        pdf_bytes = requests.get(url, stream=True).content
+
+    # Turn the PDF into an array of images
+    pages = convert_from_bytes(pdf_bytes)
+    page_total = len(pages)
+    logging.info("Document is %s pages long" % page_total)
+
+    logging.info("Determining document structure")
+    (
+        non_investment_pages,
+        investment_pages,
+        addendum_page,
+    ) = get_investment_pages(pdf_bytes)
+
+    s1 = get_text_fields(non_investment_pages)
+    document_data = identify_sections(s1)
+    results = extract_section_I_to_VI(document_data, non_investment_pages)
+
+    # Process Section VII
+    results = extract_section_VII(results, investment_pages)
+
+    # Process Section VIII - Addendum
+    addendum_data = process_addendum(addendum_page)
+    results["Additional Information or Explanations"] = addendum_data
+
+    # Calculate net worth and mark processing as a success
+    results["wealth"] = estimate_investment_net_worth(results)
+    results["success"] = True
+
+    return results
